"""
Certica - CA Certificate Generation Tool

A simple and easy-to-use tool for generating CA certificates and signing certificates
for local development and testing.
"""

__version__ = "1.2.0"
__author__ = "Metarigin"
__email__ = "dev@metarigin.com"
